.. _outputs:

Outputs
-------------------

The `Outputs` class encapsulates the output datasets and collections generated by a tool run.

.. literalinclude:: ../../tests/test_run_tool.py
    :start-after: outputs example
    :end-before: outputs example complete
    :dedent:
